package cn.com.infosec.jce.provider;

import cn.com.infosec.asn1.ASN1EncodableVector;
import cn.com.infosec.asn1.ASN1InputStream;
import cn.com.infosec.asn1.ASN1OctetString;
import cn.com.infosec.asn1.ASN1Sequence;
import cn.com.infosec.asn1.DERInteger;
import cn.com.infosec.asn1.DERNull;
import cn.com.infosec.asn1.DERObjectIdentifier;
import cn.com.infosec.asn1.DEROctetString;
import cn.com.infosec.asn1.DEROutputStream;
import cn.com.infosec.asn1.DERSequence;
import cn.com.infosec.asn1.cryptopro.GOST3410PublicKeyAlgParameters;
import cn.com.infosec.asn1.misc.IDEACBCPar;
import cn.com.infosec.asn1.oiw.ElGamalParameter;
import cn.com.infosec.asn1.pkcs.DHParameter;
import cn.com.infosec.asn1.pkcs.PKCS12PBEParams;
import cn.com.infosec.asn1.pkcs.PKCSObjectIdentifiers;
import cn.com.infosec.asn1.pkcs.RC2CBCParameter;
import cn.com.infosec.asn1.pkcs.RSAESOAEPparams;
import cn.com.infosec.asn1.pkcs.RSASSAPSSparams;
import cn.com.infosec.asn1.x509.AlgorithmIdentifier;
import cn.com.infosec.asn1.x509.DSAParameter;
import cn.com.infosec.jce.spec.ElGamalParameterSpec;
import cn.com.infosec.jce.spec.GOST3410ParameterSpec;
import cn.com.infosec.jce.spec.IESParameterSpec;
import java.io.ByteArrayOutputStream;
import java.io.IOException;
import java.math.BigInteger;
import java.security.AlgorithmParametersSpi;
import java.security.spec.AlgorithmParameterSpec;
import java.security.spec.DSAParameterSpec;
import java.security.spec.InvalidParameterSpecException;
import java.security.spec.MGF1ParameterSpec;
import java.security.spec.PSSParameterSpec;
import javax.crypto.spec.DHParameterSpec;
import javax.crypto.spec.IvParameterSpec;
import javax.crypto.spec.OAEPParameterSpec;
import javax.crypto.spec.PBEParameterSpec;
import javax.crypto.spec.PSource;
import javax.crypto.spec.RC2ParameterSpec;

public abstract class JDKAlgorithmParameters extends AlgorithmParametersSpi {
   // $FF: synthetic field
   static Class class$0;
   // $FF: synthetic field
   static Class class$1;
   // $FF: synthetic field
   static Class class$2;
   // $FF: synthetic field
   static Class class$3;
   // $FF: synthetic field
   static Class class$4;
   // $FF: synthetic field
   static Class class$5;
   // $FF: synthetic field
   static Class class$6;
   // $FF: synthetic field
   static Class class$7;
   // $FF: synthetic field
   static Class class$8;
   // $FF: synthetic field
   static Class class$9;

   protected boolean isASN1FormatString(String format) {
      return format == null || format.equals("ASN.1");
   }

   protected AlgorithmParameterSpec engineGetParameterSpec(Class paramSpec) {
      if (paramSpec != null) {
         return this.localEngineGetParameterSpec(paramSpec);
      } else {
         throw new NullPointerException("argument to getParameterSpec must not be null");
      }
   }

   protected abstract AlgorithmParameterSpec localEngineGetParameterSpec(Class var1);

   public static class DH extends JDKAlgorithmParameters {
      DHParameterSpec currentSpec;

      protected byte[] engineGetEncoded() {
         ByteArrayOutputStream var1;
         ByteArrayOutputStream var10000 = var1 = new ByteArrayOutputStream;
         var10000.<init>();
         DEROutputStream var10001 = new DEROutputStream;
         DEROutputStream var10002 = var10001;
         var10001.<init>(var1);
         BigInteger var10005 = this.currentSpec.getP();
         DH var10006 = this;
         BigInteger var3 = this.currentSpec.getG();
         DHParameter var10003 = new DHParameter(var10005, var3, var10006.currentSpec.getL());

         try {
            var10002.writeObject(var10003);
            var10001.close();
         } catch (IOException var2) {
            throw new RuntimeException("Error encoding DHParameters");
         }

         return var10000.toByteArray();
      }

      protected byte[] engineGetEncoded(String format) {
         return this.isASN1FormatString(format) ? this.engineGetEncoded() : null;
      }

      protected AlgorithmParameterSpec localEngineGetParameterSpec(Class paramSpec) {
         Class var2;
         if ((var2 = JDKAlgorithmParameters.class$3) == null) {
            Class var10000;
            try {
               var10000 = Class.forName("javax.crypto.spec.DHParameterSpec");
            } catch (ClassNotFoundException var3) {
               throw new NoClassDefFoundError(var3.getMessage());
            }

            var2 = var10000;
            JDKAlgorithmParameters.class$3 = var10000;
         }

         if (paramSpec == var2) {
            return this.currentSpec;
         } else {
            throw new InvalidParameterSpecException("unknown parameter spec passed to DH parameters object.");
         }
      }

      protected void engineInit(AlgorithmParameterSpec paramSpec) {
         if (paramSpec instanceof DHParameterSpec) {
            this.currentSpec = (DHParameterSpec)paramSpec;
         } else {
            throw new InvalidParameterSpecException("DHParameterSpec required to initialise a Diffie-Hellman algorithm parameters object");
         }
      }

      protected void engineInit(byte[] params) {
         ASN1InputStream var2;
         var2 = new ASN1InputStream.<init>(params);

         DHParameter var10000;
         boolean var10001;
         try {
            var10000 = new DHParameter;
         } catch (ClassCastException var15) {
            var10001 = false;
            throw new IOException("Not a valid DH Parameter encoding.");
         } catch (ArrayIndexOutOfBoundsException var16) {
            var10001 = false;
            throw new IOException("Not a valid DH Parameter encoding.");
         }

         DHParameter params1;
         DHParameter var21 = params1 = var10000;

         BigInteger var19;
         try {
            var21.<init>((ASN1Sequence)var2.readObject());
            var19 = var10000.getL();
         } catch (ClassCastException var13) {
            var10001 = false;
            throw new IOException("Not a valid DH Parameter encoding.");
         } catch (ArrayIndexOutOfBoundsException var14) {
            var10001 = false;
            throw new IOException("Not a valid DH Parameter encoding.");
         }

         BigInteger var17;
         DHParameterSpec var10002;
         DHParameter var10003;
         DH var20;
         BigInteger var10004;
         DHParameterSpec var22;
         if (var19 != null) {
            try {
               var20 = this;
               var22 = new DHParameterSpec;
               var10002 = var22;
               var10003 = params1;
               var10004 = params1.getP();
            } catch (ClassCastException var11) {
               var10001 = false;
               throw new IOException("Not a valid DH Parameter encoding.");
            } catch (ArrayIndexOutOfBoundsException var12) {
               var10001 = false;
               throw new IOException("Not a valid DH Parameter encoding.");
            }

            var17 = var10004;

            try {
               var10002.<init>(var17, var10003.getG(), params1.getL().intValue());
               var20.currentSpec = var22;
            } catch (ClassCastException var9) {
               var10001 = false;
               throw new IOException("Not a valid DH Parameter encoding.");
            } catch (ArrayIndexOutOfBoundsException var10) {
               var10001 = false;
               throw new IOException("Not a valid DH Parameter encoding.");
            }
         } else {
            try {
               var20 = this;
               var22 = new DHParameterSpec;
               var10002 = var22;
               var10003 = params1;
               var10004 = params1.getP();
            } catch (ClassCastException var7) {
               var10001 = false;
               throw new IOException("Not a valid DH Parameter encoding.");
            } catch (ArrayIndexOutOfBoundsException var8) {
               var10001 = false;
               throw new IOException("Not a valid DH Parameter encoding.");
            }

            var17 = var10004;

            try {
               var10002.<init>(var17, var10003.getG());
               var20.currentSpec = var22;
            } catch (ClassCastException var5) {
               var10001 = false;
               throw new IOException("Not a valid DH Parameter encoding.");
            } catch (ArrayIndexOutOfBoundsException var6) {
               var10001 = false;
               throw new IOException("Not a valid DH Parameter encoding.");
            }
         }

         try {
            ;
         } catch (ClassCastException var3) {
            var10001 = false;
            throw new IOException("Not a valid DH Parameter encoding.");
         } catch (ArrayIndexOutOfBoundsException var4) {
            var10001 = false;
            throw new IOException("Not a valid DH Parameter encoding.");
         }
      }

      protected void engineInit(byte[] params, String format) {
         if (this.isASN1FormatString(format)) {
            this.engineInit(params);
         } else {
            throw new IOException("Unknown parameter format " + format);
         }
      }

      protected String engineToString() {
         return "Diffie-Hellman Parameters";
      }
   }

   public static class DSA extends JDKAlgorithmParameters {
      DSAParameterSpec currentSpec;

      protected byte[] engineGetEncoded() {
         ByteArrayOutputStream var1;
         ByteArrayOutputStream var10000 = var1 = new ByteArrayOutputStream;
         var10000.<init>();
         DEROutputStream var10001 = new DEROutputStream;
         DEROutputStream var10002 = var10001;
         var10001.<init>(var1);
         BigInteger var10005 = this.currentSpec.getP();
         DSA var10006 = this;
         BigInteger var3 = this.currentSpec.getQ();
         DSAParameter var10003 = new DSAParameter(var10005, var3, var10006.currentSpec.getG());

         try {
            var10002.writeObject(var10003);
            var10001.close();
         } catch (IOException var2) {
            throw new RuntimeException("Error encoding DSAParameters");
         }

         return var10000.toByteArray();
      }

      protected byte[] engineGetEncoded(String format) {
         return this.isASN1FormatString(format) ? this.engineGetEncoded() : null;
      }

      protected AlgorithmParameterSpec localEngineGetParameterSpec(Class paramSpec) {
         Class var2;
         if ((var2 = JDKAlgorithmParameters.class$4) == null) {
            Class var10000;
            try {
               var10000 = Class.forName("java.security.spec.DSAParameterSpec");
            } catch (ClassNotFoundException var3) {
               throw new NoClassDefFoundError(var3.getMessage());
            }

            var2 = var10000;
            JDKAlgorithmParameters.class$4 = var10000;
         }

         if (paramSpec == var2) {
            return this.currentSpec;
         } else {
            throw new InvalidParameterSpecException("unknown parameter spec passed to DSA parameters object.");
         }
      }

      protected void engineInit(AlgorithmParameterSpec paramSpec) {
         if (paramSpec instanceof DSAParameterSpec) {
            this.currentSpec = (DSAParameterSpec)paramSpec;
         } else {
            throw new InvalidParameterSpecException("DSAParameterSpec required to initialise a DSA algorithm parameters object");
         }
      }

      protected void engineInit(byte[] params) {
         DSA var10000 = this;
         ASN1InputStream var13;
         var13 = new ASN1InputStream.<init>(params);

         DSAParameter var17;
         boolean var10001;
         try {
            var17 = new DSAParameter;
         } catch (ClassCastException var11) {
            var10001 = false;
            throw new IOException("Not a valid DSA Parameter encoding.");
         } catch (ArrayIndexOutOfBoundsException var12) {
            var10001 = false;
            throw new IOException("Not a valid DSA Parameter encoding.");
         }

         DSAParameter params1 = var17;

         DSAParameterSpec var18;
         DSAParameterSpec var10002;
         DSAParameter var10003;
         DSAParameter var10004;
         BigInteger var10005;
         try {
            var17.<init>((ASN1Sequence)var13.readObject());
            var18 = new DSAParameterSpec;
            var10002 = var18;
            var10003 = params1;
            var10004 = params1;
            var10005 = params1.getP();
         } catch (ClassCastException var9) {
            var10001 = false;
            throw new IOException("Not a valid DSA Parameter encoding.");
         } catch (ArrayIndexOutOfBoundsException var10) {
            var10001 = false;
            throw new IOException("Not a valid DSA Parameter encoding.");
         }

         BigInteger var14 = var10005;

         BigInteger var20;
         try {
            var20 = var10004.getQ();
         } catch (ClassCastException var7) {
            var10001 = false;
            throw new IOException("Not a valid DSA Parameter encoding.");
         } catch (ArrayIndexOutOfBoundsException var8) {
            var10001 = false;
            throw new IOException("Not a valid DSA Parameter encoding.");
         }

         BigInteger params2 = var20;

         BigInteger var19;
         try {
            var19 = var10003.getG();
         } catch (ClassCastException var5) {
            var10001 = false;
            throw new IOException("Not a valid DSA Parameter encoding.");
         } catch (ArrayIndexOutOfBoundsException var6) {
            var10001 = false;
            throw new IOException("Not a valid DSA Parameter encoding.");
         }

         BigInteger var2 = var19;

         try {
            var10002.<init>(var14, params2, var2);
            var10000.currentSpec = var18;
         } catch (ClassCastException var3) {
            var10001 = false;
            throw new IOException("Not a valid DSA Parameter encoding.");
         } catch (ArrayIndexOutOfBoundsException var4) {
            var10001 = false;
            throw new IOException("Not a valid DSA Parameter encoding.");
         }
      }

      protected void engineInit(byte[] params, String format) {
         if (!this.isASN1FormatString(format) && !format.equalsIgnoreCase("X.509")) {
            throw new IOException("Unknown parameter format " + format);
         } else {
            this.engineInit(params);
         }
      }

      protected String engineToString() {
         return "DSA Parameters";
      }
   }

   public static class ElGamal extends JDKAlgorithmParameters {
      ElGamalParameterSpec currentSpec;

      protected byte[] engineGetEncoded() {
         ByteArrayOutputStream var1;
         ByteArrayOutputStream var10000 = var1 = new ByteArrayOutputStream;
         var10000.<init>();
         DEROutputStream var10001 = new DEROutputStream;
         DEROutputStream var10002 = var10001;
         var10001.<init>(var1);
         ElGamalParameter var10003 = new ElGamalParameter(this.currentSpec.getP(), this.currentSpec.getG());

         try {
            var10002.writeObject(var10003);
            var10001.close();
         } catch (IOException var2) {
            throw new RuntimeException("Error encoding ElGamalParameters");
         }

         return var10000.toByteArray();
      }

      protected byte[] engineGetEncoded(String format) {
         return !this.isASN1FormatString(format) && !format.equalsIgnoreCase("X.509") ? null : this.engineGetEncoded();
      }

      protected AlgorithmParameterSpec localEngineGetParameterSpec(Class paramSpec) {
         Class var10000;
         Class var2;
         if ((var2 = JDKAlgorithmParameters.class$6) == null) {
            try {
               var10000 = Class.forName("cn.com.infosec.jce.spec.ElGamalParameterSpec");
            } catch (ClassNotFoundException var4) {
               throw new NoClassDefFoundError(var4.getMessage());
            }

            var2 = var10000;
            JDKAlgorithmParameters.class$6 = var10000;
         }

         if (paramSpec == var2) {
            return this.currentSpec;
         } else {
            if ((var2 = JDKAlgorithmParameters.class$3) == null) {
               try {
                  var10000 = Class.forName("javax.crypto.spec.DHParameterSpec");
               } catch (ClassNotFoundException var3) {
                  throw new NoClassDefFoundError(var3.getMessage());
               }

               var2 = var10000;
               JDKAlgorithmParameters.class$3 = var10000;
            }

            if (paramSpec == var2) {
               return new DHParameterSpec(this.currentSpec.getP(), this.currentSpec.getG());
            } else {
               throw new InvalidParameterSpecException("unknown parameter spec passed to ElGamal parameters object.");
            }
         }
      }

      protected void engineInit(AlgorithmParameterSpec paramSpec) {
         boolean var2;
         if (!(var2 = paramSpec instanceof ElGamalParameterSpec) && !(paramSpec instanceof DHParameterSpec)) {
            throw new InvalidParameterSpecException("DHParameterSpec required to initialise a ElGamal algorithm parameters object");
         } else {
            if (var2) {
               this.currentSpec = (ElGamalParameterSpec)paramSpec;
            } else {
               ElGamal var10000 = this;
               DHParameterSpec var3 = (DHParameterSpec)paramSpec;
               ElGamalParameterSpec paramSpec1;
               ElGamalParameterSpec var10001 = paramSpec1 = new ElGamalParameterSpec;
               DHParameterSpec var10002 = var3;
               BigInteger var4 = var3.getP();
               var10001.<init>(var4, var10002.getG());
               var10000.currentSpec = paramSpec1;
            }

         }
      }

      protected void engineInit(byte[] params) {
         ElGamal var10000 = this;
         ASN1InputStream var8;
         var8 = new ASN1InputStream.<init>(params);

         boolean var10001;
         ElGamalParameter var11;
         try {
            var11 = new ElGamalParameter;
         } catch (ClassCastException var6) {
            var10001 = false;
            throw new IOException("Not a valid ElGamal Parameter encoding.");
         } catch (ArrayIndexOutOfBoundsException var7) {
            var10001 = false;
            throw new IOException("Not a valid ElGamal Parameter encoding.");
         }

         ElGamalParameter params1 = var11;

         ElGamalParameterSpec var10002;
         ElGamalParameter var10003;
         BigInteger var10004;
         ElGamalParameterSpec var12;
         try {
            var11.<init>((ASN1Sequence)var8.readObject());
            var12 = new ElGamalParameterSpec;
            var10002 = var12;
            var10003 = params1;
            var10004 = params1.getP();
         } catch (ClassCastException var4) {
            var10001 = false;
            throw new IOException("Not a valid ElGamal Parameter encoding.");
         } catch (ArrayIndexOutOfBoundsException var5) {
            var10001 = false;
            throw new IOException("Not a valid ElGamal Parameter encoding.");
         }

         BigInteger var9 = var10004;

         try {
            var10002.<init>(var9, var10003.getG());
            var10000.currentSpec = var12;
         } catch (ClassCastException var2) {
            var10001 = false;
            throw new IOException("Not a valid ElGamal Parameter encoding.");
         } catch (ArrayIndexOutOfBoundsException var3) {
            var10001 = false;
            throw new IOException("Not a valid ElGamal Parameter encoding.");
         }
      }

      protected void engineInit(byte[] params, String format) {
         if (!this.isASN1FormatString(format) && !format.equalsIgnoreCase("X.509")) {
            throw new IOException("Unknown parameter format " + format);
         } else {
            this.engineInit(params);
         }
      }

      protected String engineToString() {
         return "ElGamal Parameters";
      }
   }

   public static class GOST3410 extends JDKAlgorithmParameters {
      GOST3410ParameterSpec currentSpec;

      protected byte[] engineGetEncoded() {
         ByteArrayOutputStream var1;
         ByteArrayOutputStream var10000 = var1 = new ByteArrayOutputStream;
         var10000.<init>();
         DEROutputStream var10001 = new DEROutputStream;
         DEROutputStream var10002 = var10001;
         var10001.<init>(var1);
         GOST3410PublicKeyAlgParameters var10003 = new GOST3410PublicKeyAlgParameters(new DERObjectIdentifier(this.currentSpec.getPublicKeyParamSetOID()), new DERObjectIdentifier(this.currentSpec.getDigestParamSetOID()), new DERObjectIdentifier(this.currentSpec.getEncryptionParamSetOID()));

         try {
            var10002.writeObject(var10003);
            var10001.close();
         } catch (IOException var2) {
            throw new RuntimeException("Error encoding GOST3410Parameters");
         }

         return var10000.toByteArray();
      }

      protected byte[] engineGetEncoded(String format) {
         return !this.isASN1FormatString(format) && !format.equalsIgnoreCase("X.509") ? null : this.engineGetEncoded();
      }

      protected AlgorithmParameterSpec localEngineGetParameterSpec(Class paramSpec) {
         Class var2;
         if ((var2 = JDKAlgorithmParameters.class$5) == null) {
            Class var10000;
            try {
               var10000 = Class.forName("cn.com.infosec.jce.spec.GOST3410PublicKeyParameterSetSpec");
            } catch (ClassNotFoundException var3) {
               throw new NoClassDefFoundError(var3.getMessage());
            }

            var2 = var10000;
            JDKAlgorithmParameters.class$5 = var10000;
         }

         if (paramSpec == var2) {
            return this.currentSpec;
         } else {
            throw new InvalidParameterSpecException("unknown parameter spec passed to GOST3410 parameters object.");
         }
      }

      protected void engineInit(AlgorithmParameterSpec paramSpec) {
         if (paramSpec instanceof GOST3410ParameterSpec) {
            this.currentSpec = (GOST3410ParameterSpec)paramSpec;
         } else {
            throw new InvalidParameterSpecException("GOST3410ParameterSpec required to initialise a GOST3410 algorithm parameters object");
         }
      }

      protected void engineInit(byte[] param1) {
         // $FF: Couldn't be decompiled
      }

      protected void engineInit(byte[] params, String format) {
         if (!this.isASN1FormatString(format) && !format.equalsIgnoreCase("X.509")) {
            throw new IOException("Unknown parameter format " + format);
         } else {
            this.engineInit(params);
         }
      }

      protected String engineToString() {
         return "GOST3410 Parameters";
      }
   }

   public static class IDEAAlgorithmParameters extends JDKAlgorithmParameters {
      private byte[] iv;

      protected byte[] engineGetEncoded() {
         return this.engineGetEncoded("ASN.1");
      }

      protected byte[] engineGetEncoded(String format) {
         if (this.isASN1FormatString(format)) {
            return (new IDEACBCPar(this.engineGetEncoded("RAW"))).getEncoded();
         } else if (format.equals("RAW")) {
            byte[] var2;
            byte[] format1;
            byte[] var10000 = format1 = new byte[(var2 = this.iv).length];
            byte[] var10001 = var2;
            int var3 = var2.length;
            System.arraycopy(var10001, 0, format1, 0, var3);
            return var10000;
         } else {
            return null;
         }
      }

      protected AlgorithmParameterSpec localEngineGetParameterSpec(Class paramSpec) {
         Class var2;
         if ((var2 = JDKAlgorithmParameters.class$0) == null) {
            Class var10000;
            try {
               var10000 = Class.forName("javax.crypto.spec.IvParameterSpec");
            } catch (ClassNotFoundException var3) {
               throw new NoClassDefFoundError(var3.getMessage());
            }

            var2 = var10000;
            JDKAlgorithmParameters.class$0 = var10000;
         }

         if (paramSpec == var2) {
            return new IvParameterSpec(this.iv);
         } else {
            throw new InvalidParameterSpecException("unknown parameter spec passed to IV parameters object.");
         }
      }

      protected void engineInit(AlgorithmParameterSpec paramSpec) {
         if (paramSpec instanceof IvParameterSpec) {
            this.iv = ((IvParameterSpec)paramSpec).getIV();
         } else {
            throw new InvalidParameterSpecException("IvParameterSpec required to initialise a IV parameters algorithm parameters object");
         }
      }

      protected void engineInit(byte[] params) {
         byte[] var10000 = params;
         byte[] var10001 = params = new byte[params.length];
         this.iv = params;
         int var2 = var10001.length;
         System.arraycopy(var10000, 0, params, 0, var2);
      }

      protected void engineInit(byte[] params, String format) {
         if (format.equals("RAW")) {
            this.engineInit(params);
         } else if (format.equals("ASN.1")) {
            IDEAAlgorithmParameters var10000 = this;
            ASN1InputStream var3;
            var3 = new ASN1InputStream.<init>(params);
            var10000.engineInit((new IDEACBCPar((ASN1Sequence)var3.readObject())).getIV());
         } else {
            throw new IOException("Unknown parameters format in IV parameters object");
         }
      }

      protected String engineToString() {
         return "IDEA Parameters";
      }
   }

   public static class IES extends JDKAlgorithmParameters {
      IESParameterSpec currentSpec;

      protected byte[] engineGetEncoded() {
         ByteArrayOutputStream var1;
         ByteArrayOutputStream var10000 = var1 = new ByteArrayOutputStream;
         var10000.<init>();
         DEROutputStream var10001 = new DEROutputStream;
         DEROutputStream var10002 = var10001;
         var10001.<init>(var1);

         ASN1EncodableVector var10003;
         boolean var5;
         try {
            var10003 = new ASN1EncodableVector;
         } catch (IOException var3) {
            var5 = false;
            throw new RuntimeException("Error encoding IESParameters");
         }

         ASN1EncodableVector var10004 = var10003;
         ASN1EncodableVector var10005 = var10003;
         ASN1EncodableVector var4;
         ASN1EncodableVector var10006 = var4 = var10003;

         try {
            var10006.<init>();
            var10005.add(new DEROctetString(this.currentSpec.getDerivationV()));
            var10004.add(new DEROctetString(this.currentSpec.getEncodingV()));
            var10003.add(new DERInteger(this.currentSpec.getMacKeySize()));
            var10002.writeObject(new DERSequence(var4));
            var10001.close();
            return var10000.toByteArray();
         } catch (IOException var2) {
            var5 = false;
            throw new RuntimeException("Error encoding IESParameters");
         }
      }

      protected byte[] engineGetEncoded(String format) {
         return !this.isASN1FormatString(format) && !format.equalsIgnoreCase("X.509") ? null : this.engineGetEncoded();
      }

      protected AlgorithmParameterSpec localEngineGetParameterSpec(Class paramSpec) {
         Class var2;
         if ((var2 = JDKAlgorithmParameters.class$7) == null) {
            Class var10000;
            try {
               var10000 = Class.forName("cn.com.infosec.jce.spec.IESParameterSpec");
            } catch (ClassNotFoundException var3) {
               throw new NoClassDefFoundError(var3.getMessage());
            }

            var2 = var10000;
            JDKAlgorithmParameters.class$7 = var10000;
         }

         if (paramSpec == var2) {
            return this.currentSpec;
         } else {
            throw new InvalidParameterSpecException("unknown parameter spec passed to ElGamal parameters object.");
         }
      }

      protected void engineInit(AlgorithmParameterSpec paramSpec) {
         if (paramSpec instanceof IESParameterSpec) {
            this.currentSpec = (IESParameterSpec)paramSpec;
         } else {
            throw new InvalidParameterSpecException("IESParameterSpec required to initialise a IES algorithm parameters object");
         }
      }

      protected void engineInit(byte[] params) {
         IES var10000 = this;
         ASN1InputStream var10001 = new ASN1InputStream(params);

         boolean var15;
         ASN1Sequence var16;
         try {
            var16 = (ASN1Sequence)var10001.readObject();
         } catch (ClassCastException var11) {
            var15 = false;
            throw new IOException("Not a valid IES Parameter encoding.");
         } catch (ArrayIndexOutOfBoundsException var12) {
            var15 = false;
            throw new IOException("Not a valid IES Parameter encoding.");
         }

         ASN1Sequence var13 = var16;

         IESParameterSpec var17;
         IESParameterSpec var10002;
         ASN1Sequence var10003;
         ASN1Sequence var10004;
         byte[] var10005;
         try {
            var17 = new IESParameterSpec;
            var10002 = var17;
            var10003 = var13;
            var10004 = var13;
            var10005 = ((ASN1OctetString)var13.getObjectAt(0)).getOctets();
         } catch (ClassCastException var9) {
            var15 = false;
            throw new IOException("Not a valid IES Parameter encoding.");
         } catch (ArrayIndexOutOfBoundsException var10) {
            var15 = false;
            throw new IOException("Not a valid IES Parameter encoding.");
         }

         byte[] var14 = var10005;

         byte[] var19;
         try {
            var19 = ((ASN1OctetString)var10004.getObjectAt(0)).getOctets();
         } catch (ClassCastException var7) {
            var15 = false;
            throw new IOException("Not a valid IES Parameter encoding.");
         } catch (ArrayIndexOutOfBoundsException var8) {
            var15 = false;
            throw new IOException("Not a valid IES Parameter encoding.");
         }

         params = var19;

         int var18;
         try {
            var18 = ((DERInteger)var10003.getObjectAt(0)).getValue().intValue();
         } catch (ClassCastException var5) {
            var15 = false;
            throw new IOException("Not a valid IES Parameter encoding.");
         } catch (ArrayIndexOutOfBoundsException var6) {
            var15 = false;
            throw new IOException("Not a valid IES Parameter encoding.");
         }

         int var2 = var18;

         try {
            var10002.<init>(var14, params, var2);
            var10000.currentSpec = var17;
         } catch (ClassCastException var3) {
            var15 = false;
            throw new IOException("Not a valid IES Parameter encoding.");
         } catch (ArrayIndexOutOfBoundsException var4) {
            var15 = false;
            throw new IOException("Not a valid IES Parameter encoding.");
         }
      }

      protected void engineInit(byte[] params, String format) {
         if (!this.isASN1FormatString(format) && !format.equalsIgnoreCase("X.509")) {
            throw new IOException("Unknown parameter format " + format);
         } else {
            this.engineInit(params);
         }
      }

      protected String engineToString() {
         return "IES Parameters";
      }
   }

   public static class IVAlgorithmParameters extends JDKAlgorithmParameters {
      private byte[] iv;

      protected byte[] engineGetEncoded() {
         return this.engineGetEncoded("ASN.1");
      }

      protected byte[] engineGetEncoded(String format) {
         if (this.isASN1FormatString(format)) {
            return (new DEROctetString(this.engineGetEncoded("RAW"))).getEncoded();
         } else if (format.equals("RAW")) {
            byte[] var2;
            byte[] format1;
            byte[] var10000 = format1 = new byte[(var2 = this.iv).length];
            byte[] var10001 = var2;
            int var3 = var2.length;
            System.arraycopy(var10001, 0, format1, 0, var3);
            return var10000;
         } else {
            return null;
         }
      }

      protected AlgorithmParameterSpec localEngineGetParameterSpec(Class paramSpec) {
         Class var2;
         if ((var2 = JDKAlgorithmParameters.class$0) == null) {
            Class var10000;
            try {
               var10000 = Class.forName("javax.crypto.spec.IvParameterSpec");
            } catch (ClassNotFoundException var3) {
               throw new NoClassDefFoundError(var3.getMessage());
            }

            var2 = var10000;
            JDKAlgorithmParameters.class$0 = var10000;
         }

         if (paramSpec == var2) {
            return new IvParameterSpec(this.iv);
         } else {
            throw new InvalidParameterSpecException("unknown parameter spec passed to IV parameters object.");
         }
      }

      protected void engineInit(AlgorithmParameterSpec paramSpec) {
         if (paramSpec instanceof IvParameterSpec) {
            this.iv = ((IvParameterSpec)paramSpec).getIV();
         } else {
            throw new InvalidParameterSpecException("IvParameterSpec required to initialise a IV parameters algorithm parameters object");
         }
      }

      protected void engineInit(byte[] params) {
         if (params.length % 8 != 0 && params[0] == 4 && params[1] == params.length - 2) {
            params = ((ASN1OctetString)(new ASN1InputStream(params)).readObject()).getOctets();
         }

         byte[] var10000 = params;
         byte[] var10001 = params = new byte[params.length];
         this.iv = params;
         int var2 = var10001.length;
         System.arraycopy(var10000, 0, params, 0, var2);
      }

      protected void engineInit(byte[] params, String format) {
         if (this.isASN1FormatString(format)) {
            IVAlgorithmParameters var10000 = this;
            ASN1InputStream var10001 = new ASN1InputStream(params);

            try {
               var10000.engineInit(((ASN1OctetString)var10001.readObject()).getOctets());
            } catch (Exception var3) {
               throw new IOException("Exception decoding: " + var3);
            }
         } else if (format.equals("RAW")) {
            this.engineInit(params);
         } else {
            throw new IOException("Unknown parameters format in IV parameters object");
         }
      }

      protected String engineToString() {
         return "IV Parameters";
      }
   }

   public static class OAEP extends JDKAlgorithmParameters {
      OAEPParameterSpec currentSpec;

      protected byte[] engineGetEncoded() {
         ByteArrayOutputStream var1;
         ByteArrayOutputStream var10000 = var1 = new ByteArrayOutputStream;
         var10000.<init>();
         DEROutputStream var10001 = new DEROutputStream;
         DEROutputStream var2;
         DEROutputStream var10002 = var2 = var10001;
         OAEP var10003 = this;
         var2.<init>(var1);
         AlgorithmIdentifier var7;
         var7 = new AlgorithmIdentifier.<init>(JCEDigestUtil.getOID(this.currentSpec.getDigestAlgorithm()), new DERNull());
         MGF1ParameterSpec var5 = (MGF1ParameterSpec)this.currentSpec.getMGFParameters();
         AlgorithmIdentifier var8;
         var8 = new AlgorithmIdentifier.<init>(PKCSObjectIdentifiers.id_mgf1, new AlgorithmIdentifier(JCEDigestUtil.getOID(var5.getDigestAlgorithm()), new DERNull()));
         PSource.PSpecified var6 = (PSource.PSpecified)var10003.currentSpec.getPSource();
         AlgorithmIdentifier var3;
         var3 = new AlgorithmIdentifier.<init>(PKCSObjectIdentifiers.id_pSpecified, new DEROctetString(var6.getValue()));
         RSAESOAEPparams var9 = new RSAESOAEPparams(var7, var8, var3);

         try {
            var10002.writeObject(var9);
            var10001.close();
         } catch (IOException var4) {
            throw new RuntimeException("Error encoding OAEPParameters");
         }

         return var10000.toByteArray();
      }

      protected byte[] engineGetEncoded(String format) {
         return !this.isASN1FormatString(format) && !format.equalsIgnoreCase("X.509") ? null : this.engineGetEncoded();
      }

      protected AlgorithmParameterSpec localEngineGetParameterSpec(Class paramSpec) {
         Class var2;
         if ((var2 = JDKAlgorithmParameters.class$8) == null) {
            Class var10000;
            try {
               var10000 = Class.forName("javax.crypto.spec.OAEPParameterSpec");
            } catch (ClassNotFoundException var3) {
               throw new NoClassDefFoundError(var3.getMessage());
            }

            var2 = var10000;
            JDKAlgorithmParameters.class$8 = var10000;
         }

         OAEPParameterSpec var4;
         if (paramSpec == var2 && (var4 = this.currentSpec) != null) {
            return var4;
         } else {
            throw new InvalidParameterSpecException("unknown parameter spec passed to OAEP parameters object.");
         }
      }

      protected void engineInit(AlgorithmParameterSpec paramSpec) {
         if (paramSpec instanceof OAEPParameterSpec) {
            this.currentSpec = (OAEPParameterSpec)paramSpec;
         } else {
            throw new InvalidParameterSpecException("OAEPParameterSpec required to initialise an OAEP algorithm parameters object");
         }
      }

      protected void engineInit(byte[] params) {
         OAEP var10000 = this;
         ASN1InputStream var6;
         var6 = new ASN1InputStream.<init>(params);

         boolean var10001;
         RSAESOAEPparams var8;
         try {
            var8 = new RSAESOAEPparams;
         } catch (ClassCastException var4) {
            var10001 = false;
            throw new IOException("Not a valid OAEP Parameter encoding.");
         } catch (ArrayIndexOutOfBoundsException var5) {
            var10001 = false;
            throw new IOException("Not a valid OAEP Parameter encoding.");
         }

         RSAESOAEPparams params1 = var8;

         try {
            var8.<init>((ASN1Sequence)var6.readObject());
            var10000.currentSpec = new OAEPParameterSpec(params1.getHashAlgorithm().getObjectId().getId(), params1.getMaskGenAlgorithm().getObjectId().getId(), new MGF1ParameterSpec(AlgorithmIdentifier.getInstance(params1.getMaskGenAlgorithm().getParameters()).getObjectId().getId()), new PSource.PSpecified(ASN1OctetString.getInstance(params1.getPSourceAlgorithm().getParameters()).getOctets()));
         } catch (ClassCastException var2) {
            var10001 = false;
            throw new IOException("Not a valid OAEP Parameter encoding.");
         } catch (ArrayIndexOutOfBoundsException var3) {
            var10001 = false;
            throw new IOException("Not a valid OAEP Parameter encoding.");
         }
      }

      protected void engineInit(byte[] params, String format) {
         if (!format.equalsIgnoreCase("X.509") && !format.equalsIgnoreCase("ASN.1")) {
            throw new IOException("Unknown parameter format " + format);
         } else {
            this.engineInit(params);
         }
      }

      protected String engineToString() {
         return "OAEP Parameters";
      }
   }

   public static class PKCS12PBE extends JDKAlgorithmParameters {
      PKCS12PBEParams params;

      protected byte[] engineGetEncoded() {
         ByteArrayOutputStream var1;
         ByteArrayOutputStream var10000 = var1 = new ByteArrayOutputStream;
         var10000.<init>();
         PKCS12PBE var10002 = this;
         DEROutputStream var10001 = new DEROutputStream(var1);

         try {
            var10001.writeObject(var10002.params);
         } catch (IOException var2) {
            throw new RuntimeException("Oooops! " + var2.toString());
         }

         return var10000.toByteArray();
      }

      protected byte[] engineGetEncoded(String format) {
         return this.isASN1FormatString(format) ? this.engineGetEncoded() : null;
      }

      protected AlgorithmParameterSpec localEngineGetParameterSpec(Class paramSpec) {
         Class var2;
         if ((var2 = JDKAlgorithmParameters.class$2) == null) {
            Class var10000;
            try {
               var10000 = Class.forName("javax.crypto.spec.PBEParameterSpec");
            } catch (ClassNotFoundException var3) {
               throw new NoClassDefFoundError(var3.getMessage());
            }

            var2 = var10000;
            JDKAlgorithmParameters.class$2 = var10000;
         }

         if (paramSpec == var2) {
            return new PBEParameterSpec(this.params.getIV(), this.params.getIterations().intValue());
         } else {
            throw new InvalidParameterSpecException("unknown parameter spec passed to PKCS12 PBE parameters object.");
         }
      }

      protected void engineInit(AlgorithmParameterSpec paramSpec) {
         if (paramSpec instanceof PBEParameterSpec) {
            PKCS12PBE var10000 = this;
            PBEParameterSpec var2 = (PBEParameterSpec)paramSpec;
            PKCS12PBEParams paramSpec1;
            PKCS12PBEParams var10001 = paramSpec1 = new PKCS12PBEParams;
            PBEParameterSpec var10002 = var2;
            byte[] var3 = var2.getSalt();
            var10001.<init>(var3, var10002.getIterationCount());
            var10000.params = paramSpec1;
         } else {
            throw new InvalidParameterSpecException("PBEParameterSpec required to initialise a PKCS12 PBE parameters algorithm parameters object");
         }
      }

      protected void engineInit(byte[] params) {
         this.params = PKCS12PBEParams.getInstance((new ASN1InputStream(params)).readObject());
      }

      protected void engineInit(byte[] params, String format) {
         if (this.isASN1FormatString(format)) {
            this.engineInit(params);
         } else {
            throw new IOException("Unknown parameters format in PKCS12 PBE parameters object");
         }
      }

      protected String engineToString() {
         return "PKCS12 PBE Parameters";
      }
   }

   public static class PSS extends JDKAlgorithmParameters {
      PSSParameterSpec currentSpec;

      protected byte[] engineGetEncoded() {
         PSSParameterSpec var4;
         PSSParameterSpec var10000 = var4 = this.currentSpec;
         AlgorithmIdentifier var1;
         var1 = new AlgorithmIdentifier.<init>(JCEDigestUtil.getOID(var4.getDigestAlgorithm()), new DERNull());
         MGF1ParameterSpec var2 = (MGF1ParameterSpec)var10000.getMGFParameters();
         AlgorithmIdentifier var3;
         var3 = new AlgorithmIdentifier.<init>(PKCSObjectIdentifiers.id_mgf1, new AlgorithmIdentifier(JCEDigestUtil.getOID(var2.getDigestAlgorithm()), new DERNull()));
         AlgorithmIdentifier var10002 = var1;
         DERInteger var5;
         var5 = new DERInteger.<init>(var4.getSaltLength());
         DERInteger var6;
         var6 = new DERInteger.<init>(var4.getTrailerField());
         return (new RSASSAPSSparams(var10002, var3, var5, var6)).getEncoded("DER");
      }

      protected byte[] engineGetEncoded(String format) {
         return !format.equalsIgnoreCase("X.509") && !format.equalsIgnoreCase("ASN.1") ? null : this.engineGetEncoded();
      }

      protected AlgorithmParameterSpec localEngineGetParameterSpec(Class paramSpec) {
         Class var2;
         if ((var2 = JDKAlgorithmParameters.class$9) == null) {
            Class var10000;
            try {
               var10000 = Class.forName("java.security.spec.PSSParameterSpec");
            } catch (ClassNotFoundException var3) {
               throw new NoClassDefFoundError(var3.getMessage());
            }

            var2 = var10000;
            JDKAlgorithmParameters.class$9 = var10000;
         }

         PSSParameterSpec var4;
         if (paramSpec == var2 && (var4 = this.currentSpec) != null) {
            return var4;
         } else {
            throw new InvalidParameterSpecException("unknown parameter spec passed to PSS parameters object.");
         }
      }

      protected void engineInit(AlgorithmParameterSpec paramSpec) {
         if (paramSpec instanceof PSSParameterSpec) {
            this.currentSpec = (PSSParameterSpec)paramSpec;
         } else {
            throw new InvalidParameterSpecException("PSSParameterSpec required to initialise an PSS algorithm parameters object");
         }
      }

      protected void engineInit(byte[] params) {
         PSS var10000 = this;
         ASN1InputStream var16;
         var16 = new ASN1InputStream.<init>(params);

         boolean var10001;
         RSASSAPSSparams var20;
         try {
            var20 = new RSASSAPSSparams;
         } catch (ClassCastException var14) {
            var10001 = false;
            throw new IOException("Not a valid PSS Parameter encoding.");
         } catch (ArrayIndexOutOfBoundsException var15) {
            var10001 = false;
            throw new IOException("Not a valid PSS Parameter encoding.");
         }

         RSASSAPSSparams params1 = var20;

         PSSParameterSpec var10002;
         String var10003;
         RSASSAPSSparams var10004;
         PSSParameterSpec var21;
         RSASSAPSSparams var10005;
         String var10006;
         try {
            var20.<init>((ASN1Sequence)var16.readObject());
            var21 = new PSSParameterSpec;
            var10002 = var21;
            var10003 = params1.getHashAlgorithm().getObjectId().getId();
            var10004 = params1;
            var10005 = params1;
            var10006 = params1.getMaskGenAlgorithm().getObjectId().getId();
         } catch (ClassCastException var12) {
            var10001 = false;
            throw new IOException("Not a valid PSS Parameter encoding.");
         } catch (ArrayIndexOutOfBoundsException var13) {
            var10001 = false;
            throw new IOException("Not a valid PSS Parameter encoding.");
         }

         String var17 = var10006;

         MGF1ParameterSpec var24;
         try {
            var24 = new MGF1ParameterSpec;
         } catch (ClassCastException var10) {
            var10001 = false;
            throw new IOException("Not a valid PSS Parameter encoding.");
         } catch (ArrayIndexOutOfBoundsException var11) {
            var10001 = false;
            throw new IOException("Not a valid PSS Parameter encoding.");
         }

         MGF1ParameterSpec var2 = var24;

         int var23;
         try {
            var24.<init>(AlgorithmIdentifier.getInstance(params1.getMaskGenAlgorithm().getParameters()).getObjectId().getId());
            var23 = var10005.getSaltLength().getValue().intValue();
         } catch (ClassCastException var8) {
            var10001 = false;
            throw new IOException("Not a valid PSS Parameter encoding.");
         } catch (ArrayIndexOutOfBoundsException var9) {
            var10001 = false;
            throw new IOException("Not a valid PSS Parameter encoding.");
         }

         int params2 = var23;

         int var22;
         try {
            var22 = var10004.getTrailerField().getValue().intValue();
         } catch (ClassCastException var6) {
            var10001 = false;
            throw new IOException("Not a valid PSS Parameter encoding.");
         } catch (ArrayIndexOutOfBoundsException var7) {
            var10001 = false;
            throw new IOException("Not a valid PSS Parameter encoding.");
         }

         int var3 = var22;

         try {
            var10002.<init>(var10003, var17, var2, params2, var3);
            var10000.currentSpec = var21;
         } catch (ClassCastException var4) {
            var10001 = false;
            throw new IOException("Not a valid PSS Parameter encoding.");
         } catch (ArrayIndexOutOfBoundsException var5) {
            var10001 = false;
            throw new IOException("Not a valid PSS Parameter encoding.");
         }
      }

      protected void engineInit(byte[] params, String format) {
         if (!this.isASN1FormatString(format) && !format.equalsIgnoreCase("X.509")) {
            throw new IOException("Unknown parameter format " + format);
         } else {
            this.engineInit(params);
         }
      }

      protected String engineToString() {
         return "PSS Parameters";
      }
   }

   public static class RC2AlgorithmParameters extends JDKAlgorithmParameters {
      private short[] table;
      private short[] ekb;
      private byte[] iv;
      private int parameterVersion;

      public RC2AlgorithmParameters() {
         RC2AlgorithmParameters var10000 = this;
         RC2AlgorithmParameters var10001 = this;
         RC2AlgorithmParameters var10002 = this;
         super();
         short[] var1;
         short[] var10003 = var1 = new short[256];
         var10003[0] = 189;
         var10003[1] = 86;
         var10003[2] = 234;
         var10003[3] = 242;
         var10003[4] = 162;
         var10003[5] = 241;
         var10003[6] = 172;
         var10003[7] = 42;
         var10003[8] = 176;
         var10003[9] = 147;
         var10003[10] = 209;
         var10003[11] = 156;
         var10003[12] = 27;
         var10003[13] = 51;
         var10003[14] = 253;
         var10003[15] = 208;
         var10003[16] = 48;
         var10003[17] = 4;
         var10003[18] = 182;
         var10003[19] = 220;
         var10003[20] = 125;
         var10003[21] = 223;
         var10003[22] = 50;
         var10003[23] = 75;
         var10003[24] = 247;
         var10003[25] = 203;
         var10003[26] = 69;
         var10003[27] = 155;
         var10003[28] = 49;
         var10003[29] = 187;
         var10003[30] = 33;
         var10003[31] = 90;
         var10003[32] = 65;
         var10003[33] = 159;
         var10003[34] = 225;
         var10003[35] = 217;
         var10003[36] = 74;
         var10003[37] = 77;
         var10003[38] = 158;
         var10003[39] = 218;
         var10003[40] = 160;
         var10003[41] = 104;
         var10003[42] = 44;
         var10003[43] = 195;
         var10003[44] = 39;
         var10003[45] = 95;
         var10003[46] = 128;
         var10003[47] = 54;
         var10003[48] = 62;
         var10003[49] = 238;
         var10003[50] = 251;
         var10003[51] = 149;
         var10003[52] = 26;
         var10003[53] = 254;
         var10003[54] = 206;
         var10003[55] = 168;
         var10003[56] = 52;
         var10003[57] = 169;
         var10003[58] = 19;
         var10003[59] = 240;
         var10003[60] = 166;
         var10003[61] = 63;
         var10003[62] = 216;
         var10003[63] = 12;
         var10003[64] = 120;
         var10003[65] = 36;
         var10003[66] = 175;
         var10003[67] = 35;
         var10003[68] = 82;
         var10003[69] = 193;
         var10003[70] = 103;
         var10003[71] = 23;
         var10003[72] = 245;
         var10003[73] = 102;
         var10003[74] = 144;
         var10003[75] = 231;
         var10003[76] = 232;
         var10003[77] = 7;
         var10003[78] = 184;
         var10003[79] = 96;
         var10003[80] = 72;
         var10003[81] = 230;
         var10003[82] = 30;
         var10003[83] = 83;
         var10003[84] = 243;
         var10003[85] = 146;
         var10003[86] = 164;
         var10003[87] = 114;
         var10003[88] = 140;
         var10003[89] = 8;
         var10003[90] = 21;
         var10003[91] = 110;
         var10003[92] = 134;
         var10003[94] = 132;
         var10003[95] = 250;
         var10003[96] = 244;
         var10003[97] = 127;
         var10003[98] = 138;
         var10003[99] = 66;
         var10003[100] = 25;
         var10003[101] = 246;
         var10003[102] = 219;
         var10003[103] = 205;
         var10003[104] = 20;
         var10003[105] = 141;
         var10003[106] = 80;
         var10003[107] = 18;
         var10003[108] = 186;
         var10003[109] = 60;
         var10003[110] = 6;
         var10003[111] = 78;
         var10003[112] = 236;
         var10003[113] = 179;
         var10003[114] = 53;
         var10003[115] = 17;
         var10003[116] = 161;
         var10003[117] = 136;
         var10003[118] = 142;
         var10003[119] = 43;
         var10003[120] = 148;
         var10003[121] = 153;
         var10003[122] = 183;
         var10003[123] = 113;
         var10003[124] = 116;
         var10003[125] = 211;
         var10003[126] = 228;
         var10003[127] = 191;
         var10003[128] = 58;
         var10003[129] = 222;
         var10003[130] = 150;
         var10003[131] = 14;
         var10003[132] = 188;
         var10003[133] = 10;
         var10003[134] = 237;
         var10003[135] = 119;
         var10003[136] = 252;
         var10003[137] = 55;
         var10003[138] = 107;
         var10003[139] = 3;
         var10003[140] = 121;
         var10003[141] = 137;
         var10003[142] = 98;
         var10003[143] = 198;
         var10003[144] = 215;
         var10003[145] = 192;
         var10003[146] = 210;
         var10003[147] = 124;
         var10003[148] = 106;
         var10003[149] = 139;
         var10003[150] = 34;
         var10003[151] = 163;
         var10003[152] = 91;
         var10003[153] = 5;
         var10003[154] = 93;
         var10003[155] = 2;
         var10003[156] = 117;
         var10003[157] = 213;
         var10003[158] = 97;
         var10003[159] = 227;
         var10003[160] = 24;
         var10003[161] = 143;
         var10003[162] = 85;
         var10003[163] = 81;
         var10003[164] = 173;
         var10003[165] = 31;
         var10003[166] = 11;
         var10003[167] = 94;
         var10003[168] = 133;
         var10003[169] = 229;
         var10003[170] = 194;
         var10003[171] = 87;
         var10003[172] = 99;
         var10003[173] = 202;
         var10003[174] = 61;
         var10003[175] = 108;
         var10003[176] = 180;
         var10003[177] = 197;
         var10003[178] = 204;
         var10003[179] = 112;
         var10003[180] = 178;
         var10003[181] = 145;
         var10003[182] = 89;
         var10003[183] = 13;
         var10003[184] = 71;
         var10003[185] = 32;
         var10003[186] = 200;
         var10003[187] = 79;
         var10003[188] = 88;
         var10003[189] = 224;
         var10003[190] = 1;
         var10003[191] = 226;
         var10003[192] = 22;
         var10003[193] = 56;
         var10003[194] = 196;
         var10003[195] = 111;
         var10003[196] = 59;
         var10003[197] = 15;
         var10003[198] = 101;
         var10003[199] = 70;
         var10003[200] = 190;
         var10003[201] = 126;
         var10003[202] = 45;
         var10003[203] = 123;
         var10003[204] = 130;
         var10003[205] = 249;
         var10003[206] = 64;
         var10003[207] = 181;
         var10003[208] = 29;
         var10003[209] = 115;
         var10003[210] = 248;
         var10003[211] = 235;
         var10003[212] = 38;
         var10003[213] = 199;
         var10003[214] = 135;
         var10003[215] = 151;
         var10003[216] = 37;
         var10003[217] = 84;
         var10003[218] = 177;
         var10003[219] = 40;
         var10003[220] = 170;
         var10003[221] = 152;
         var10003[222] = 157;
         var10003[223] = 165;
         var10003[224] = 100;
         var10003[225] = 109;
         var10003[226] = 122;
         var10003[227] = 212;
         var10003[228] = 16;
         var10003[229] = 129;
         var10003[230] = 68;
         var10003[231] = 239;
         var10003[232] = 73;
         var10003[233] = 214;
         var10003[234] = 174;
         var10003[235] = 46;
         var10003[236] = 221;
         var10003[237] = 118;
         var10003[238] = 92;
         var10003[239] = 47;
         var10003[240] = 167;
         var10003[241] = 28;
         var10003[242] = 201;
         var10003[243] = 9;
         var10003[244] = 105;
         var10003[245] = 154;
         var10003[246] = 131;
         var10003[247] = 207;
         var10003[248] = 41;
         var10003[249] = 57;
         var10003[250] = 185;
         var10003[251] = 233;
         var10003[252] = 76;
         var10003[253] = 255;
         var10003[254] = 67;
         var10003[255] = 171;
         var10002.table = var1;
         short[] var2 = var1 = new short[256];
         var2[0] = 93;
         var2[1] = 190;
         var2[2] = 155;
         var2[3] = 139;
         var2[4] = 17;
         var2[5] = 153;
         var2[6] = 110;
         var2[7] = 77;
         var2[8] = 89;
         var2[9] = 243;
         var2[10] = 133;
         var2[11] = 166;
         var2[12] = 63;
         var2[13] = 183;
         var2[14] = 131;
         var2[15] = 197;
         var2[16] = 228;
         var2[17] = 115;
         var2[18] = 107;
         var2[19] = 58;
         var2[20] = 104;
         var2[21] = 90;
         var2[22] = 192;
         var2[23] = 71;
         var2[24] = 160;
         var2[25] = 100;
         var2[26] = 52;
         var2[27] = 12;
         var2[28] = 241;
         var2[29] = 208;
         var2[30] = 82;
         var2[31] = 165;
         var2[32] = 185;
         var2[33] = 30;
         var2[34] = 150;
         var2[35] = 67;
         var2[36] = 65;
         var2[37] = 216;
         var2[38] = 212;
         var2[39] = 44;
         var2[40] = 219;
         var2[41] = 248;
         var2[42] = 7;
         var2[43] = 119;
         var2[44] = 42;
         var2[45] = 202;
         var2[46] = 235;
         var2[47] = 239;
         var2[48] = 16;
         var2[49] = 28;
         var2[50] = 22;
         var2[51] = 13;
         var2[52] = 56;
         var2[53] = 114;
         var2[54] = 47;
         var2[55] = 137;
         var2[56] = 193;
         var2[57] = 249;
         var2[58] = 128;
         var2[59] = 196;
         var2[60] = 109;
         var2[61] = 174;
         var2[62] = 48;
         var2[63] = 61;
         var2[64] = 206;
         var2[65] = 32;
         var2[66] = 99;
         var2[67] = 254;
         var2[68] = 230;
         var2[69] = 26;
         var2[70] = 199;
         var2[71] = 184;
         var2[72] = 80;
         var2[73] = 232;
         var2[74] = 36;
         var2[75] = 23;
         var2[76] = 252;
         var2[77] = 37;
         var2[78] = 111;
         var2[79] = 187;
         var2[80] = 106;
         var2[81] = 163;
         var2[82] = 68;
         var2[83] = 83;
         var2[84] = 217;
         var2[85] = 162;
         var2[86] = 1;
         var2[87] = 171;
         var2[88] = 188;
         var2[89] = 182;
         var2[90] = 31;
         var2[91] = 152;
         var2[92] = 238;
         var2[93] = 154;
         var2[94] = 167;
         var2[95] = 45;
         var2[96] = 79;
         var2[97] = 158;
         var2[98] = 142;
         var2[99] = 172;
         var2[100] = 224;
         var2[101] = 198;
         var2[102] = 73;
         var2[103] = 70;
         var2[104] = 41;
         var2[105] = 244;
         var2[106] = 148;
         var2[107] = 138;
         var2[108] = 175;
         var2[109] = 225;
         var2[110] = 91;
         var2[111] = 195;
         var2[112] = 179;
         var2[113] = 123;
         var2[114] = 87;
         var2[115] = 209;
         var2[116] = 124;
         var2[117] = 156;
         var2[118] = 237;
         var2[119] = 135;
         var2[120] = 64;
         var2[121] = 140;
         var2[122] = 226;
         var2[123] = 203;
         var2[124] = 147;
         var2[125] = 20;
         var2[126] = 201;
         var2[127] = 97;
         var2[128] = 46;
         var2[129] = 229;
         var2[130] = 204;
         var2[131] = 246;
         var2[132] = 94;
         var2[133] = 168;
         var2[134] = 92;
         var2[135] = 214;
         var2[136] = 117;
         var2[137] = 141;
         var2[138] = 98;
         var2[139] = 149;
         var2[140] = 88;
         var2[141] = 105;
         var2[142] = 118;
         var2[143] = 161;
         var2[144] = 74;
         var2[145] = 181;
         var2[146] = 85;
         var2[147] = 9;
         var2[148] = 120;
         var2[149] = 51;
         var2[150] = 130;
         var2[151] = 215;
         var2[152] = 221;
         var2[153] = 121;
         var2[154] = 245;
         var2[155] = 27;
         var2[156] = 11;
         var2[157] = 222;
         var2[158] = 38;
         var2[159] = 33;
         var2[160] = 40;
         var2[161] = 116;
         var2[162] = 4;
         var2[163] = 151;
         var2[164] = 86;
         var2[165] = 223;
         var2[166] = 60;
         var2[167] = 240;
         var2[168] = 55;
         var2[169] = 57;
         var2[170] = 220;
         var2[171] = 255;
         var2[172] = 6;
         var2[173] = 164;
         var2[174] = 234;
         var2[175] = 66;
         var2[176] = 8;
         var2[177] = 218;
         var2[178] = 180;
         var2[179] = 113;
         var2[180] = 176;
         var2[181] = 207;
         var2[182] = 18;
         var2[183] = 122;
         var2[184] = 78;
         var2[185] = 250;
         var2[186] = 108;
         var2[187] = 29;
         var2[188] = 132;
         var2[190] = 200;
         var2[191] = 127;
         var2[192] = 145;
         var2[193] = 69;
         var2[194] = 170;
         var2[195] = 43;
         var2[196] = 194;
         var2[197] = 177;
         var2[198] = 143;
         var2[199] = 213;
         var2[200] = 186;
         var2[201] = 242;
         var2[202] = 173;
         var2[203] = 25;
         var2[204] = 178;
         var2[205] = 103;
         var2[206] = 54;
         var2[207] = 247;
         var2[208] = 15;
         var2[209] = 10;
         var2[210] = 146;
         var2[211] = 125;
         var2[212] = 227;
         var2[213] = 157;
         var2[214] = 233;
         var2[215] = 144;
         var2[216] = 62;
         var2[217] = 35;
         var2[218] = 39;
         var2[219] = 102;
         var2[220] = 19;
         var2[221] = 236;
         var2[222] = 129;
         var2[223] = 21;
         var2[224] = 189;
         var2[225] = 34;
         var2[226] = 191;
         var2[227] = 159;
         var2[228] = 126;
         var2[229] = 169;
         var2[230] = 81;
         var2[231] = 75;
         var2[232] = 76;
         var2[233] = 251;
         var2[234] = 2;
         var2[235] = 211;
         var2[236] = 112;
         var2[237] = 134;
         var2[238] = 49;
         var2[239] = 231;
         var2[240] = 59;
         var2[241] = 5;
         var2[242] = 3;
         var2[243] = 84;
         var2[244] = 96;
         var2[245] = 72;
         var2[246] = 101;
         var2[247] = 24;
         var2[248] = 210;
         var2[249] = 205;
         var2[250] = 95;
         var2[251] = 50;
         var2[252] = 136;
         var2[253] = 14;
         var2[254] = 53;
         var2[255] = 253;
         var10001.ekb = var1;
         var10000.parameterVersion = 58;
      }

      protected byte[] engineGetEncoded() {
         byte[] var1;
         byte[] var2;
         byte[] var10000 = var1 = new byte[(var2 = this.iv).length];
         byte[] var10001 = var2;
         int var3 = var2.length;
         System.arraycopy(var10001, 0, var1, 0, var3);
         return var10000;
      }

      protected byte[] engineGetEncoded(String format) {
         if (this.isASN1FormatString(format)) {
            int format1;
            return (format1 = this.parameterVersion) == -1 ? (new RC2CBCParameter(this.engineGetEncoded())).getEncoded() : (new RC2CBCParameter(format1, this.engineGetEncoded())).getEncoded();
         } else {
            return format.equals("RAW") ? this.engineGetEncoded() : null;
         }
      }

      protected AlgorithmParameterSpec localEngineGetParameterSpec(Class paramSpec) {
         Class var10000;
         Class var2;
         if ((var2 = JDKAlgorithmParameters.class$1) == null) {
            try {
               var10000 = Class.forName("javax.crypto.spec.RC2ParameterSpec");
            } catch (ClassNotFoundException var4) {
               throw new NoClassDefFoundError(var4.getMessage());
            }

            var2 = var10000;
            JDKAlgorithmParameters.class$1 = var10000;
         }

         int var7;
         if (paramSpec == var2 && (var7 = this.parameterVersion) != -1) {
            RC2AlgorithmParameters var10002;
            if (var7 < 256) {
               var10002 = this;
               short var6 = this.ekb[this.parameterVersion];
               return new RC2ParameterSpec(var6, var10002.iv);
            } else {
               var10002 = this;
               int var5 = this.parameterVersion;
               return new RC2ParameterSpec(var5, var10002.iv);
            }
         } else {
            if ((var2 = JDKAlgorithmParameters.class$0) == null) {
               try {
                  var10000 = Class.forName("javax.crypto.spec.IvParameterSpec");
               } catch (ClassNotFoundException var3) {
                  throw new NoClassDefFoundError(var3.getMessage());
               }

               var2 = var10000;
               JDKAlgorithmParameters.class$0 = var10000;
            }

            if (paramSpec == var2) {
               return new IvParameterSpec(this.iv);
            } else {
               throw new InvalidParameterSpecException("unknown parameter spec passed to RC2 parameters object.");
            }
         }
      }

      protected void engineInit(AlgorithmParameterSpec paramSpec) {
         if (paramSpec instanceof IvParameterSpec) {
            this.iv = ((IvParameterSpec)paramSpec).getIV();
         } else {
            if (!(paramSpec instanceof RC2ParameterSpec)) {
               throw new InvalidParameterSpecException("IvParameterSpec or RC2ParameterSpec required to initialise a RC2 parameters algorithm parameters object");
            }

            int var2;
            RC2ParameterSpec paramSpec1;
            if ((var2 = (paramSpec1 = (RC2ParameterSpec)paramSpec).getEffectiveKeyBits()) != -1) {
               if (var2 < 256) {
                  this.parameterVersion = this.table[var2];
               } else {
                  this.parameterVersion = var2;
               }
            }

            this.iv = paramSpec1.getIV();
         }

      }

      protected void engineInit(byte[] params) {
         byte[] var10000 = params;
         byte[] var10001 = params = new byte[params.length];
         this.iv = params;
         int var2 = var10001.length;
         System.arraycopy(var10000, 0, params, 0, var2);
      }

      protected void engineInit(byte[] params, String format) {
         if (this.isASN1FormatString(format)) {
            RC2CBCParameter params1;
            if ((params1 = RC2CBCParameter.getInstance((new ASN1InputStream(params)).readObject())).getRC2ParameterVersion() != null) {
               this.parameterVersion = params1.getRC2ParameterVersion().intValue();
            }

            this.iv = params1.getIV();
         } else if (format.equals("RAW")) {
            this.engineInit(params);
         } else {
            throw new IOException("Unknown parameters format in IV parameters object");
         }
      }

      protected String engineToString() {
         return "RC2 Parameters";
      }
   }
}
